package com.medm.devicekit.sample

import android.app.Activity
import android.content.Intent
import android.provider.Settings
import android.util.Log
import androidx.activity.ComponentActivity
import androidx.activity.result.IntentSenderRequest
import androidx.activity.result.contract.ActivityResultContracts
import com.google.android.gms.common.ConnectionResult
import com.google.android.gms.common.GoogleApiAvailability
import com.google.android.gms.common.api.ResolvableApiException
import com.google.android.gms.location.*

class LocationServicesRequester(private val activity: ComponentActivity)
{
    interface Listener
    {
        fun onResult(granted: Boolean)
    }

    private var mListener: Listener? = null
    private val mRequester = activity.registerForActivityResult(ActivityResultContracts.StartIntentSenderForResult()) {
        mListener?.onResult(it.resultCode == Activity.RESULT_OK)
        mListener = null
    }

    fun requestTurnOn(listener: Listener)
    {
        Log.d("DeviceKitSample", "requestLocationServices")
        mListener = listener
        if (!playServicesAvailable(activity))
        {
            activity.startActivity(Intent(Settings.ACTION_LOCATION_SOURCE_SETTINGS))
        } else
        {
            val builder = LocationSettingsRequest.Builder()
                    .addLocationRequest(LocationRequest.Builder(Priority.PRIORITY_LOW_POWER, 60000).build())
                    .setAlwaysShow(true)

            LocationServices.getSettingsClient(activity).checkLocationSettings(builder.build()).addOnCompleteListener { result ->

                if (result.isSuccessful)
                {
                    listener.onResult(true)
                } else if (result.exception is ResolvableApiException)
                {
                    mRequester.launch(IntentSenderRequest.Builder((result.exception as ResolvableApiException).resolution).build())
                } else
                {
                    listener.onResult(false)
                }
            }
        }
    }

    private fun playServicesAvailable(activity: Activity): Boolean
    {
        return GoogleApiAvailability.getInstance().isGooglePlayServicesAvailable(activity) == ConnectionResult.SUCCESS
    }
}